<!DOCTYPE html>
<html lang="en">
<head>
  <meta charset="utf-8">
  <title>{% block title %}{% endblock %} - MoePad</title>

  <meta name="viewport" content="width=device-width, initial-scale=1.0">
  <meta name="description" content="">
  <meta name="author" content="delo">

  <!-- Le styles -->
  <!-- "/static/css/bootstrap.css" -->
  {% load staticfiles %}
  <link href="{% static "css/bootstrap.css" %}" rel="stylesheet">
  <link href="/static/css/docs.css" rel="stylesheet">
  <link rel="stylesheet" href="/static/css/bootstrap-tagsinput.css">
  {% block custom_css %}{% endblock %}
  <style>
      body {
        padding-top: 60px; /* 60px to make the container go all the way to the bottom of the topbar */
      }
    </style>
  <link href="/static/css/bootstrap-responsive.css" rel="stylesheet">
  <link href="/static/css/mp.css" rel="stylesheet">

  <!-- HTML5 shim, for IE6-8 support of HTML5 elements -->
  <!--[if lt IE 9]>
  <script src="js/html5shiv.js"></script>
  <![endif]-->

  <!-- Fav and touch icons -->
  <link rel="apple-touch-icon-precomposed" sizes="144x144" href="ico/apple-touch-icon-144-precomposed.png">
  <link rel="apple-touch-icon-precomposed" sizes="114x114" href="ico/apple-touch-icon-114-precomposed.png">
  <link rel="apple-touch-icon-precomposed" sizes="72x72" href="ico/apple-touch-icon-72-precomposed.png">
  <link rel="apple-touch-icon-precomposed" href="ico/apple-touch-icon-57-precomposed.png">
  <link rel="shortcut icon" href="ico/favicon.png"></head>

<body data-spy="scroll" data-target=".bs-docs-sidebar">

  <div class="navbar navbar-inverse navbar-fixed-top">
    <div class="navbar-inner">
      <div class="container">
        <button type="button" class="btn btn-navbar" data-toggle="collapse" data-target=".nav-collapse">
          <span class="icon-bar"></span>
          <span class="icon-bar"></span>
          <span class="icon-bar"></span>
        </button>
        <a class="brand" href="#">moepad config</a>
        <div class="nav-collapse collapse">
          <ul class="nav">
            <li>
              <a href="/">首页</a>
            </li>
            <li>
              <a href="/verify/">待审核新词条</a>
            </li>
            <li>
              <a href="/forbidden/">禁止项管理</a>
            </li>
          </ul>
        </div>
        <!--/.nav-collapse --> </div>
    </div>
  </div>

  <div class="container">

    <h1>{% block h1 %}{% endblock %}</h1>
    <h2>{% block h2 %}{% endblock %}</h2>
    {% block content %}{% endblock %}

  </div>
  <!-- /container -->

  <script src="/static/js/jquery.js"></script>
  <script src="/static/js/bootstrap.js"></script>
  <script src="/static/js/prettify.js"></script>
  <script src="/static/js/bootstrap-tagsinput.min.js"></script>
  {% block tailscript %}{% endblock %}

</body>
</html>