{% extends "base.html" %}

{% block title %}mpconfig{% endblock %}

{% block content %}
<div class="content">

<div class="side_box" id="buttons">
	<p>进行帐户认证前请确认右边的app key/secret信息已填写正确</p>
	<a href="/clean_auth/" class="span2 btn funcbtn btn-danger">清除认证信息</a><br/>
	<a href="/loginSina/original/" class="span2 btn funcbtn btn-primary">新浪发送帐户认证</a><br/>	
</div>
<div class="px20"></div>
<div class="span6 nice_box" id="config_form">

	<form id="mpconfig" action="/" method="post" class="span6">
		{% csrf_token %}
		<p>带 * 的为必填项，留空意味着从数据库里清空此字段</p>
		{% if error_list %}
			{% for error in error_list %}
				<div class="error_list"><p>{{error}}</p></div>
			{% endfor %}
		{% endif %}

		<form id="mpconfig" action="" method="post">
		{% csrf_token %}
		{{form}}
		<br>
		<input class="btn-success btn span1 " type="submit" value="提交"/>
			

		</form>
<!-- 
		{% for field in field_list %}

		<label for="{{field.input_id}}" class="inlinelabel span2">{{field.field_name}}</label>
		<input class="span3" name="{{field.input_id}}" type="text" value="{{field.value}}"/>
		<br/>
		{% endfor %} -->

		<div class="span4 inlinelabel"></div>
	</form>

</div>

</div>

{% endblock %}